@@ -555,7 +555,7 @@ Examples:
             $self->info("In $prefix/$category");
 
             if (! -d File::Spec->catdir($self->root, $category)) {
-                return $plugin->render_client_error("Invalid category requested: '$category'");
+                $plugin->dsl->pass();
             }
             my $articles = $self->select_articles(category => $category, limit => 6);
             $self->info("retrieved ".scalar(@$articles)." articles");
